@@ -124,7 +124,7 @@ using namespace std;
 FstStore::FstStore(std::string fstFile)
 {
   this->fstFile       = fstFile;
-  this->blockReader   = nullptr;
+  // this->blockReader   = nullptr;
   this->keyColPos     = nullptr;
   this->p_nrOfRows    = nullptr;
   metaDataBlock       = nullptr;
@@ -136,7 +136,7 @@ FstStore::FstStore(std::string fstFile)
  * \param myfile a stream to a fst file
  * \param keyLength the number of key columns (output)
  * \param nrOfColsFirstChunk the number of columns in the first chunkset (output)
- * \return 
+ * \return
  */
 inline unsigned int ReadHeader(ifstream &myfile, int &keyLength, int &nrOfColsFirstChunk)
 {
@@ -207,7 +207,7 @@ inline void SetKeyIndex(vector<int> &keyIndex, const int keyLength, const int nr
 /**
  * \brief Write a dataset to a fst file
  * \param fstTable interface to a dataset
- * \param compress compression factor in the range 0 - 100 
+ * \param compress compression factor in the range 0 - 100
  */
 void FstStore::fstWrite(IFstTable &fstTable, const int compress) const
 {
@@ -296,7 +296,7 @@ void FstStore::fstWrite(IFstTable &fstTable, const int compress) const
   const bool isLittleEndian = (*reinterpret_cast<uint8_t*>(&endianTest)) == 0x67;
 
   // Set table header parameters
-  
+
   *p_tableFlags = 0;
   *p_tableVersion                   = FST_VERSION;
 
@@ -537,7 +537,7 @@ void FstStore::fstWrite(IFstTable &fstTable, const int compress) const
 }
 
 
-void FstStore::fstMeta(IColumnFactory* columnFactory)
+void FstStore::fstMeta(IColumnFactory* columnFactory, IStringColumn* col_names)
 {
   // fst file stream using a stack buffer
   ifstream myfile;
@@ -630,10 +630,8 @@ void FstStore::fstMeta(IColumnFactory* columnFactory)
   // Read column names
   const unsigned long long colNamesOffset = metaSize + TABLE_META_SIZE;
 
-  blockReaderP = std::unique_ptr<IStringColumn>(columnFactory->CreateStringColumn(nrOfCols, FstColumnAttribute::NONE));
-  blockReader = blockReaderP.get();
-
-  fdsReadCharVec_v6(myfile, blockReader, colNamesOffset, 0, static_cast<unsigned int>(nrOfCols), static_cast<unsigned int>(nrOfCols));
+  col_names->AllocateVec(static_cast<unsigned int>(nrOfCols));
+  fdsReadCharVec_v6(myfile, col_names, colNamesOffset, 0, static_cast<unsigned int>(nrOfCols), static_cast<unsigned int>(nrOfCols));
 
   // cleanup
   myfile.close();
@@ -641,7 +639,7 @@ void FstStore::fstMeta(IColumnFactory* columnFactory)
 
 
 void FstStore::fstRead(IFstTable &tableReader, IStringArray* columnSelection, const long long startRow, const long long endRow,
-  IColumnFactory* columnFactory, vector<int> &keyIndex, IStringArray* selectedCols)
+  IColumnFactory* columnFactory, vector<int> &keyIndex, IStringArray* selectedCols, IStringColumn* col_names)
 {
   // fst file stream using a stack buffer
   ifstream myfile;
@@ -689,7 +687,7 @@ void FstStore::fstRead(IFstTable &tableReader, IStringArray* columnSelection, co
   }
 
   // Chunkset header [node C, free leaf of A or other chunkset header] [size: 80 + 8 * nrOfCols]
-  
+
   unsigned long long* p_chunksetHash      = reinterpret_cast<unsigned long long*>(&metaDataBlock[keyIndexHeaderSize]);
   //unsigned int* p_chunksetHeaderVersion   = reinterpret_cast<unsigned int*>(&metaDataBlock[keyIndexHeaderSize + 8]);
   //int* p_chunksetFlags                    = reinterpret_cast<int*>(&metaDataBlock[keyIndexHeaderSize + 12]);
@@ -736,10 +734,11 @@ void FstStore::fstRead(IFstTable &tableReader, IStringArray* columnSelection, co
 
   const unsigned long long colNamesOffset = metaSize + TABLE_META_SIZE;
 
-  blockReaderP = std::unique_ptr<IStringColumn>(columnFactory->CreateStringColumn(nrOfCols, FstColumnAttribute::NONE));
-  blockReader = blockReaderP.get();
+  // blockReaderP = std::unique_ptr<IStringColumn>(columnFactory->CreateStringColumn(nrOfCols, FstColumnAttribute::NONE));
+  // blockReader = blockReaderP.get();
 
-  fdsReadCharVec_v6(myfile, blockReader, colNamesOffset, 0, static_cast<unsigned int>(nrOfCols), static_cast<unsigned int>(nrOfCols));
+  col_names->AllocateVec(static_cast<unsigned int>(nrOfCols));
+  fdsReadCharVec_v6(myfile, col_names, colNamesOffset, 0, static_cast<unsigned int>(nrOfCols), static_cast<unsigned int>(nrOfCols));
 
   // Size of chunkset index header plus data chunk header
   const unsigned long long chunkIndexSize = CHUNK_INDEX_SIZE + DATA_INDEX_SIZE + 8 * nrOfCols;
@@ -822,7 +821,7 @@ void FstStore::fstRead(IFstTable &tableReader, IStringArray* columnSelection, co
 
       for (int colNr = 0; colNr < nrOfCols; ++colNr)
       {
-        const char* str2 = blockReader->GetElement(colNr);
+        const char* str2 = col_names->GetElement(colNr);
         if (strcmp(str1, str2) == 0)
         {
           equal = colNr;
@@ -894,8 +893,12 @@ void FstStore::fstRead(IFstTable &tableReader, IStringArray* columnSelection, co
       {
         std::unique_ptr<IStringColumn> stringColumnP(columnFactory->CreateStringColumn(length, static_cast<FstColumnAttribute>(colAttributeTypes[colNr])));
         IStringColumn* stringColumn = stringColumnP.get();
-        fdsReadCharVec_v6(myfile, stringColumn, pos, firstRow, length, nrOfRows);
+
+        stringColumn->AllocateVec(static_cast<unsigned int>(length));
         tableReader.SetStringColumn(stringColumn, colSel);
+
+        fdsReadCharVec_v6(myfile, stringColumn, pos, firstRow, length, nrOfRows);
+
         break;
       }
 
@@ -905,17 +908,19 @@ void FstStore::fstRead(IFstTable &tableReader, IStringArray* columnSelection, co
         std::unique_ptr<IIntegerColumn> integerColumnP(columnFactory->CreateIntegerColumn(length, static_cast<FstColumnAttribute>(colAttributeTypes[colNr]), scale));
         IIntegerColumn* integerColumn = integerColumnP.get();
 
+        tableReader.SetIntegerColumn(integerColumn, colSel);
+
         std::string annotation = "";
         bool hasAnnotation;
+
         fdsReadIntVec_v8(myfile, integerColumn->Data(), pos, firstRow, length, nrOfRows, annotation, hasAnnotation);
 
         if (hasAnnotation)
         {
-          tableReader.SetIntegerColumn(integerColumn, colSel, annotation);
+          integerColumn->Annotate(annotation);
           break;
         }
 
-        tableReader.SetIntegerColumn(integerColumn, colSel);
         break;
       }
 
@@ -925,17 +930,18 @@ void FstStore::fstRead(IFstTable &tableReader, IStringArray* columnSelection, co
         std::unique_ptr<IDoubleColumn> doubleColumnP(columnFactory->CreateDoubleColumn(length, static_cast<FstColumnAttribute>(colAttributeTypes[colNr]), scale));
         IDoubleColumn* doubleColumn = doubleColumnP.get();
 
+        tableReader.SetDoubleColumn(doubleColumn, colSel);
+
         std::string annotation = "";
         bool hasAnnotation;
+
         fdsReadRealVec_v9(myfile, doubleColumn->Data(), pos, firstRow, length, nrOfRows, annotation, hasAnnotation);
 
         if (hasAnnotation)
         {
-          tableReader.SetDoubleColumn(doubleColumn, colSel, annotation);
-          break;
+          doubleColumn->Annotate(annotation);
         }
 
-        tableReader.SetDoubleColumn(doubleColumn, colSel);
         break;
       }
 
@@ -944,18 +950,17 @@ void FstStore::fstRead(IFstTable &tableReader, IStringArray* columnSelection, co
       {
         std::unique_ptr<ILogicalColumn> logicalColumnP(columnFactory->CreateLogicalColumn(length, static_cast<FstColumnAttribute>(colAttributeTypes[colNr])));
         ILogicalColumn* logicalColumn = logicalColumnP.get();
-        fdsReadLogicalVec_v10(myfile, logicalColumn->Data(), pos, firstRow, length, nrOfRows);
         tableReader.SetLogicalColumn(logicalColumn, colSel);
+        fdsReadLogicalVec_v10(myfile, logicalColumn->Data(), pos, firstRow, length, nrOfRows);
         break;
       }
 
       // Factor vector
       case 7:
       {
-        std::unique_ptr<IFactorColumn> factorColumnP(columnFactory->CreateFactorColumn(length, static_cast<FstColumnAttribute>(colAttributeTypes[colNr])));
-        IFactorColumn* factorColumn = factorColumnP.get();
-        fdsReadFactorVec_v7(myfile, factorColumn->Levels(), factorColumn->LevelData(), pos, firstRow, length, nrOfRows);
-        tableReader.SetFactorColumn(factorColumn, colSel);
+        FstColumnAttribute col_attribute = static_cast<FstColumnAttribute>(colAttributeTypes[colNr]);
+        fdsReadFactorVec_v7(tableReader, myfile, pos, firstRow, length, nrOfRows, col_attribute, columnFactory, colSel);
+
         break;
       }
 
@@ -964,8 +969,8 @@ void FstStore::fstRead(IFstTable &tableReader, IStringArray* columnSelection, co
 	  {
       std::unique_ptr<IInt64Column> int64ColumP(columnFactory->CreateInt64Column(length, static_cast<FstColumnAttribute>(colAttributeTypes[colNr]), scale));
 	    IInt64Column* int64Column = int64ColumP.get();
-      fdsReadInt64Vec_v11(myfile, int64Column->Data(), pos, firstRow, length, nrOfRows);
 	    tableReader.SetInt64Column(int64Column, colSel);
+	    fdsReadInt64Vec_v11(myfile, int64Column->Data(), pos, firstRow, length, nrOfRows);
 	    break;
 	  }
 
@@ -974,8 +979,8 @@ void FstStore::fstRead(IFstTable &tableReader, IStringArray* columnSelection, co
 	  {
       std::unique_ptr<IByteColumn> byteColumnP(columnFactory->CreateByteColumn(length, static_cast<FstColumnAttribute>(colAttributeTypes[colNr])));
       IByteColumn* byteColumn = byteColumnP.get();
-		  fdsReadByteVec_v12(myfile, byteColumn->Data(), pos, firstRow, length, nrOfRows);
 		  tableReader.SetByteColumn(byteColumn, colSel);
+		  fdsReadByteVec_v12(myfile, byteColumn->Data(), pos, firstRow, length, nrOfRows);
 		  break;
 	  }
 
@@ -990,11 +995,15 @@ void FstStore::fstRead(IFstTable &tableReader, IStringArray* columnSelection, co
   // Key index
   SetKeyIndex(keyIndex, keyLength, nrOfSelect, keyColPos, colIndex);
 
-  selectedCols->AllocateArray(nrOfSelect);
-  selectedCols->SetEncoding(blockReader->GetEncoding());
+  // TODO: if all columns are selected, no copy is required!
+
+  selectedCols->AllocateArray(nrOfSelect);  // allocate column names
+  tableReader.SetColNames(&*selectedCols);  // set on result table
+
+  selectedCols->SetEncoding(col_names->GetEncoding());
 
   for (int i = 0; i < nrOfSelect; ++i)
   {
-    selectedCols->SetElement(i, blockReader->GetElement(colIndex[i]));
+    selectedCols->SetElement(i, col_names->GetElement(colIndex[i]));
   }
 }
