@@ -12,8 +12,8 @@ Check these declarations against the C/Fortran source code.
 extern SEXP _fst_fstcomp(SEXP, SEXP, SEXP, SEXP);
 extern SEXP _fst_fstdecomp(SEXP);
 extern SEXP _fst_fsthasher(SEXP, SEXP, SEXP);
-extern SEXP _fst_fstmetadata(SEXP, SEXP);
-extern SEXP _fst_fstretrieve(SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _fst_fstmetadata(SEXP);
+extern SEXP _fst_fstretrieve(SEXP, SEXP, SEXP, SEXP);
 extern SEXP _fst_fststore(SEXP, SEXP, SEXP, SEXP);
 extern SEXP _fst_getnrofthreads();
 extern SEXP _fst_hasopenmp();
@@ -27,8 +27,8 @@ static const R_CallMethodDef CallEntries[] = {
   {"_fst_fstcomp",            (DL_FUNC) &_fst_fstcomp,            4},
   {"_fst_fstdecomp",          (DL_FUNC) &_fst_fstdecomp,          1},
   {"_fst_fsthasher",          (DL_FUNC) &_fst_fsthasher,          3},
-  {"_fst_fstmetadata",        (DL_FUNC) &_fst_fstmetadata,        2},
-  {"_fst_fstretrieve",        (DL_FUNC) &_fst_fstretrieve,        5},
+  {"_fst_fstmetadata",        (DL_FUNC) &_fst_fstmetadata,        1},
+  {"_fst_fstretrieve",        (DL_FUNC) &_fst_fstretrieve,        4},
   {"_fst_fststore",           (DL_FUNC) &_fst_fststore,           4},
   {"_fst_getnrofthreads",     (DL_FUNC) &_fst_getnrofthreads,     0},
   {"_fst_hasopenmp",          (DL_FUNC) &_fst_hasopenmp,          0},
